==> arm-compute-library_19.11.orig.tar.xz: arm-compute-library-19.11/arm_compute/core/NEON/wrapper/intrinsics/sin.h <==
/*
 * Copyright (c) 2019 ARM Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef __ARM_COMPUTE_WRAPPER_SIN_H__
#define __ARM_COMPUTE_WRAPPER_SIN_H__

#include "arm_compute/core/NEON/NEMath.h"
#include <arm_neon.h>

namespace arm_compute
{
namespace wrapper
{
#define VSIN_IMPL(vtype, prefix, postfix) \
    inline vtype vsin(const vtype &a)     \
    {                                     \
        return prefix##_##postfix(a);     \
    }

VSIN_IMPL(float32x4_t, vsinq, f32)
#ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
VSIN_IMPL(float16x8_t, vsinq, f16)
#endif // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC

#undef vsub_IMPL
} // namespace wrapper
} // namespace arm_compute
#endif /* __ARM_COMPUTE_WRAPPER_SUB_H__ */

==> arm-compute-library_20.08+dfsg.orig.tar.xz: arm-compute-library-20.08+dfsg/arm_compute/core/NEON/wrapper/intrinsics/sin.h <==
/*
 * Copyright (c) 2019-2020 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef ARM_COMPUTE_WRAPPER_SIN_H
#define ARM_COMPUTE_WRAPPER_SIN_H

#include "arm_compute/core/NEON/NEMath.h"
#include <arm_neon.h>

namespace arm_compute
{
namespace wrapper
{
#define VSIN_IMPL(vtype, prefix, postfix) \
    inline vtype vsin(const vtype &a)     \
    {                                     \
        return prefix##_##postfix(a);     \
    }

#define VSIN_IMPL_INT(vtype, prefix, postfix) \
    inline vtype vsin(const vtype &a)         \
    {                                         \
        ARM_COMPUTE_UNUSED(a);                \
        ARM_COMPUTE_ERROR("Not supported");   \
    }

VSIN_IMPL(float32x4_t, vsinq, f32)
#ifdef __ARM_FEATURE_FP16_VECTOR_ARITHMETIC
VSIN_IMPL(float16x8_t, vsinq, f16)
#endif // __ARM_FEATURE_FP16_VECTOR_ARITHMETIC

VSIN_IMPL_INT(int32x4_t, vsinq, s32)

#undef vsub_IMPL
} // namespace wrapper
} // namespace arm_compute
#endif /* ARM_COMPUTE_WRAPPER_SUB_H */
